@@ -5,7 +5,7 @@
 
 test_that("setKmax", {
 
-  load(test_path("ce.RData"))
+  load(test_path("testdata", "ce.RData"))
   
   m <- bcea(e = eff,
             c = cost,
@@ -23,7 +23,7 @@ test_that("setKmax", {
 
 test_that("setReferenceGroup", {
   
-  load(test_path("ce.RData"))
+  load(test_path("testdata", "ce.RData"))
   
   m <- bcea(e = eff,
             c = cost,
@@ -40,7 +40,7 @@ test_that("setReferenceGroup", {
 
 test_that("setComparison", {
   
-  load(test_path("ce.RData"))
+  load(test_path("testdata", "ce.RData"))
   
   m_r1 <- bcea(e = eff,
                c = cost,
